# pyromaji
Romaji to Hiragana conversion library

## Install
```bash
pip install pyromaji
```

## Usage
```python
from pyromaji import romaji

# きょうはいいてんきだ
romaji.conv("kyouhaiitennkida")
```

## Performance
![](doc/performance.png)